@@ -1,8 +1,9 @@
 import time
 
 import numpy
+
 from benchmarks.benchmark_func import benchmark_func
-from warg.pooled_queue_processor import PooledQueueProcessor, PooledQueueTask
+from draugr.multiprocessing_utilities.pooled_queue_processor import PooledQueueProcessor, PooledQueueTask
 
 
 class Zeroes(PooledQueueTask):
